package UserInterface;

/**
 * @author Costas Vandikas (vandikas@csd.uoc.gr)
 */

import javax.swing.JDialog;
import javax.swing.JTextArea;
import javax.swing.JTable;
import javax.swing.JScrollPane;
import java.util.Vector;
import java.awt.Container;
import java.awt.BorderLayout;
import TextDatabase.DocumentTreeSet;
import TextDatabase.Document;

/**
 * Observes the document analysis
 */
public class DocumentViewerDialog extends JDialog
{
	/**
     * Holds the document
     */
	private Document _document;
	/**
     * Holds the documents text
     */
	private JScrollPane _documentScrollPane;
	/**
     * Holds the document's keywords
     */
	private JScrollPane _keywordsScrollPane;
	/**
     * Holds the column names for the document's keywords table
     */
	private Vector _keywordColumns;
	/**
     * Holds the dialog's content pane
     */
	private Container _contentPane;
	/**
     * Holds the width of the dialog
     */
	private final int _width = 600;
	/**
     * Holds the height of the dialog
     */
	private final int _height = 500;

	/**
     * Initializes the Document Viewer Dialog from a document
     */
	public DocumentViewerDialog( Document Document )
	{
		init();	
		setDocument(Document);
	}

	/**
     * Dialog initialization
     */
	private void init()
	{
		_contentPane = getContentPane();
		_contentPane.setLayout( new BorderLayout() );
		
		_keywordColumns = new Vector();
		_keywordColumns.add( "Keyword" );
		_keywordColumns.add( "Frequency" );
		_keywordColumns.add( "Normalized Frequency" );
		_keywordColumns.add( "Inverse Frequency" );
		_keywordColumns.add( "Term Weight" );

		setSize(_width, _height);
		setResizable(false);
	}

	/**
     * Sets the document
     */
	public void setDocument( Document Document )
	{
		_document = Document;
		PopulateDialog();
	}

	/**
     * Populates the Document Dialog with the document
     */
	private void PopulateDialog()
	{
		setTitle( _document.getFileName() );

		_keywordsScrollPane = new JScrollPane(
				new ReadOnlyTable( _document.toVector(), _keywordColumns ));
		
		JTextArea documentTextArea = 
			new JTextArea( _document.getText(), 10, 50 );
		documentTextArea.setEditable(false);
		_documentScrollPane = new JScrollPane(documentTextArea);
		
		_contentPane.add( _documentScrollPane, BorderLayout.NORTH );
		_contentPane.add( _keywordsScrollPane, BorderLayout.CENTER );
	}
}