package TextDatabase;

/**
 * @author Costas Vandikas (vandikas@csd.uoc.gr)
 */

import java.util.Iterator;
import java.util.TreeSet;

/**
 * The KeywordTreeSet is a TreeSet of keywords
 */
public class KeywordTreeSet extends TreeSet
{
	/**
     * Holds the keyword with the highest frequency
     */
	protected Keyword _mostPopularKeyword;

	/**
     * Adds a keyword to the collection while managing the keyword's frequency
     * and mantains the record of the most popular keyword
     */
	public int addKeyword( String string )
	{
		Iterator iterator = iterator();
		Keyword keyword = getKeyword( string );
		if ( keyword != null )
		{
			int frequency = keyword.getFrequency()+1;
			keyword.setFrequency( frequency );
			if ( frequency > getMostPopularKeywordFrequency() )
				_mostPopularKeyword = keyword;
				
			return frequency;
		}
		
		Keyword newKeyword = new Keyword( string, 1 );
		if ( _mostPopularKeyword == null )
			_mostPopularKeyword = newKeyword;
		
		add( newKeyword );
		
		return 1;
	}

	/**
     * Returns true if a keywordname exists in the tree set
     */
	public boolean contains( String KeywordName )
	{
		return contains( new Keyword( KeywordName ) );
	}

	/**
     * Gets the normalized frequency of a keywordName
     * Normalized Frequency = 
     *	keyword's frequency / most popular keyword's frequency
     */
	public double getNormalizedFrequency( String KeywordName )
	{
		return getNormalizedFrequency( getKeyword( KeywordName ) );
	}
	
	/**
     * Gets the normalized frequency of a keywordName
     * Normalized Frequency = 
     *	keyword's frequency / most popular keyword's frequency
     */
	public double getNormalizedFrequency( Keyword Keyword )
	{
		if ( Keyword != null )
			return (double)Keyword.getFrequency() / 
				getMostPopularKeywordFrequency();
				
		return 0;
	}

	/**
     * Returns the most popular keyword's frequency
     */
	public int getMostPopularKeywordFrequency()
	{
		return _mostPopularKeyword.getFrequency();
	}

	/**
     * Gets the Keyword whose keyword name is KeywordName
     */
	public Keyword getKeyword( String KeywordName )
	{
		Iterator iterator = iterator();
		while ( iterator.hasNext() )
		{
			Keyword keyword = (Keyword)iterator.next();
			if ( keyword.equals(KeywordName) )
				return keyword;
		}
		
		return null;
	}
}