package UserInterface;

/**
 * @author Costas Vandikas (vandikas@csd.uoc.gr)
 */

import javax.swing.JFrame;
import java.awt.Container;
import java.awt.BorderLayout;
import java.awt.event.WindowEvent;
import java.awt.event.WindowAdapter;
import TextDatabase.DocumentTreeSet;
import SearchOperations.SearchEngine;
import SearchOperations.Query;

/**
 * The Main Frame is the Master Container and beholder of the User Interface
 */
public class MainFrame extends JFrame
{
	/**
     * Holds the search Panel
     */
	private SearchPanel _searchPanel;
	/**
     * Holds the result Panel
     */
	private ResultPanel _resultPanel;
	/**
     * Holds the Main Frame's width
     */
	private final int _width = 640;
	/**
     * Holds the Main Frame's height
     */
	private final int _height = 380;
	/**
     * Holds the document Tree Set
     */
	private DocumentTreeSet _documentTreeSet;

	/**
     * Initializes the Main Frame and places all panels to their proper
     * positions.
     */
	public MainFrame()
	{
		Container contentPane = getContentPane();
		setSize(_width, _height);
		setTitle("TextRetrieval");

		contentPane.setLayout( new BorderLayout() );
		addWindowListener( new MainFrameAdapter() );
		
		_documentTreeSet = new DocumentTreeSet();
		_searchPanel = new SearchPanel();
		_resultPanel = new ResultPanel();

		contentPane.add( _searchPanel, BorderLayout.NORTH );
		contentPane.add( _resultPanel, BorderLayout.CENTER );
		
		setVisible(true);
	}

	/**
     * Sets the contents of the Result Panel. It fetches the relevant documents
     * for the boolean model table and the document rankings for the 
     * vector model table.
     */
	public void setResults()
	{
		Query query = _searchPanel.getQuery();
		_resultPanel.setResults( 
			SearchEngine.getRelevantDocuments( query, _documentTreeSet ),
			SearchEngine.getDocumentRankings( query, _documentTreeSet )	);
		paintAll(getGraphics());
	}
	
	/**
     * Gets the active document tree set
     */
	public DocumentTreeSet getDocumentTreeSet()
	{
		return _documentTreeSet;
	}

	/**
     * Window Adapter class that handles Main Adapter Window Events
     */
	private class MainFrameAdapter extends WindowAdapter
	{
		/**
	     * Handles the window closing event - shuts down the application
	     */
		public void windowClosing(WindowEvent e)
		{
			dispose();
			System.exit(0);
		}
	}

	/**
     * Main function that initiates the application
     */
	public static void main(String args[])
	{
		MainFrame mainFrame = new MainFrame();

		int mode = 0;
		try
		{
			mode = Integer.parseInt(args[0]);	
		}
		catch( Exception x )
		{
		}
		finally
		{
			Application.Mode = mode;
		}
	}
}