package UserInterface;

/**
 * @author Costas Vandikas (vandikas@csd.uoc.gr)
 */

import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import javax.swing.JScrollPane;
import javax.swing.BoxLayout;
import javax.swing.DefaultCellEditor;
import javax.swing.table.TableColumn;
import javax.swing.table.TableCellEditor;
import java.util.Vector;
import TextDatabase.DocumentTreeSet;
import TextDatabase.Document;

/**
 * Result Panel contains two columns with the results for each Search Model
 */
public class ResultPanel extends ChildPanel
{
	/**
     * Scroll Pane for the results of the Boolean Model
     */
	private JScrollPane _booleanScrollPane;
	/**
     * Scroll Pane for the results of the Vector Model
     */
	private JScrollPane _vectorScrollPane;
	/**
     * Vector for the column Names of the boolean Model
     */
	private Vector _booleanColumnNames;
	/**
     * Vector for the column names of the Vector Model
     */
	private Vector _vectorColumnNames;

	/**
     * Initializes the Result Panel and the column names for each model
     */
	public ResultPanel()
	{
		setLayout( new BoxLayout( this, BoxLayout.X_AXIS ) );
		
		_booleanColumnNames = new Vector();
		_booleanColumnNames.add( "Document Name" );
		
		_vectorColumnNames = new Vector();
		_vectorColumnNames.add( "Document Name" );
		_vectorColumnNames.add( "Rank" );
	}

	/**
     * Populates the Tables with the results of each model
     */
	public void setResults( Vector BooleanVector, Vector VectorVector )
	{
		DocumentMouseAdapter documentMouseAdapter = 
			new DocumentMouseAdapter( 
				((MainFrame)getMasterContainer()).getDocumentTreeSet() );
		
		removeAll();

		ReadOnlyTable booleanTable = 
			new ReadOnlyTable( BooleanVector, _booleanColumnNames );
		booleanTable.addMouseListener( documentMouseAdapter );
		
		_booleanScrollPane = new JScrollPane(booleanTable);
		add( _booleanScrollPane );

		ReadOnlyTable vectorTable = 
			new ReadOnlyTable( VectorVector, _vectorColumnNames );
		vectorTable.addMouseListener( documentMouseAdapter );
		_vectorScrollPane = new JScrollPane(vectorTable);
		add( _vectorScrollPane );
	}

	/**
     * Mouse Adapter class for handling the Mouse Events of a Table
     */
	private class DocumentMouseAdapter extends MouseAdapter
	{
		/**
	     * Holds the active documentTreeSet
	     */
		private DocumentTreeSet _documentTreeSet;
		
		/**
	     * Initializes the Document Mouse Adapter with the active
	     * document Tree Set
	     */
		public DocumentMouseAdapter( DocumentTreeSet DocumentTreeSet )
		{
			_documentTreeSet = DocumentTreeSet;
		}

		/**
	     * Launches the Document Viewer Dialog for the selected document.
	     */
		public void mouseClicked( MouseEvent e )
		{
			if ( e.getClickCount() == 2 )
			{
				ReadOnlyTable table = (ReadOnlyTable)e.getSource();
				int row = table.rowAtPoint( e.getPoint() );
				int column = table.columnAtPoint( e.getPoint() );
				if ( column == 0 )
				{
					Document document = _documentTreeSet.getDocument( 
						table.getValueAt(row,column).toString() );
					DocumentViewerDialog documentViewerDialog = 
						new DocumentViewerDialog( document );
					documentViewerDialog.show();
				}
			}
		}
	}
}