package SearchOperations;

/**
 * @author Costas Vandikas (vandikas@csd.uoc.gr)
 */

import java.util.Vector;
import java.util.Iterator;
import TextDatabase.Document;
import TextDatabase.DocumentTreeSet;

/**
 * Facilitates the searching activities of the application
 */
public class SearchEngine
{
	/**
     * Gets a vector with the relevant documents that satisfy the query.
     * It is used for implementing the boolean search model and passes the
     * query to each document in order to recognize the document's relativity
     * to the query.
     */
	public static Vector getRelevantDocuments( Query Query, 
		DocumentTreeSet DocumentTreeSet )
	{
		Iterator documentIterator = DocumentTreeSet.iterator();
		Vector mainVector = new Vector();
		while ( documentIterator.hasNext() )
		{
			Document document = (Document)documentIterator.next();
			if ( document.isRelevant( Query ) )
			{
				Vector innerVector = new Vector();
				innerVector.add( document.getFileName() );
				mainVector.add( innerVector );
			}
		}
		
		return mainVector;
	}

	/**
     * Gets a vector with document rankings derived from the document term
     * weights and the query term weights. If a document's rank is NaN it means
     * that the document does not contain the specified term and it is not
     * included in the output vector. This function implements the Vector 
     * Search Model. The result is sorted in descending order.
     */
	public static Vector getDocumentRankings( Query Query, 
		DocumentTreeSet DocumentTreeSet )
	{
		Vector mainVector = new Vector();
		Iterator iterator = DocumentTreeSet.iterator();

		while( iterator.hasNext() )
		{
			Document document = (Document)iterator.next();
			double documentRank = DocumentTreeSet.getDocumentRank( 
				Query, document );
			
			if ( !Double.isNaN(documentRank) && documentRank != 0 )
			{
				Vector innerVector = new Vector();
				innerVector.add( document.toString() );
				innerVector.add( Double.toString(documentRank) );
				mainVector.add( innerVector );
			}
		}
		
		bubbleSort(mainVector);
		return mainVector;
	}

	/**
     * Bubble sorts a vector
     */
	private static void bubbleSort( Vector inputVector )
	{
		for( int k=0; k<inputVector.size()-1; k++ )
		{
			for ( int i=0; i<inputVector.size()-k-1; i++ )
			{
				Vector currentVector = ((Vector)inputVector.elementAt(i));
				Vector nextVector = ((Vector)inputVector.elementAt(i+1));
				double number = Double.parseDouble( 
					currentVector.elementAt(1).toString() );
				double nextNumber = Double.parseDouble( 
					nextVector.elementAt(1).toString() );
				if ( number < nextNumber )
				{
					inputVector.setElementAt(nextVector,i);
					inputVector.setElementAt(currentVector,i+1);
				}
			}
		}
	}
}