package UserInterface;

/**
 * @author Costas Vandikas (vandikas@csd.uoc.gr)
 */

import java.awt.FlowLayout;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JTextField;
import javax.swing.JOptionPane;
import java.util.TreeSet;
import SearchOperations.Query;

/**
 * The Search Panel is a ChildPanel that implements the Searching part
 * of the User Interface
 */
public class SearchPanel extends ChildPanel implements ActionListener
{
	/**
     * Holds the search expression
     */
	private JTextField _searchTextField;
	/**
     * Holds the button that initiates the search sequence
     */
	private JButton _searchButton;
	/**
     * Search Label
     */
	private JLabel _label;

	/**
     * Holds the length of the search expression
     */
	private int _textLength = 40;

	/**
     * Initiates the Search panel and it's action listeners
     */
	public SearchPanel()
	{
		setLayout( new FlowLayout() );
		
		_searchTextField = new JTextField( _textLength );
		_searchButton = new JButton( "Search" );
		_label = new JLabel( "Search For:" );
		
		add( _label );
		add( _searchTextField );
		add( _searchButton );
		
		_searchButton.addActionListener(this);
		_searchTextField.addActionListener(this);
	}

	/**
     * Initiates the search sequence when the return button is pressed or the
     * search button is clicked, but first it validates the search expression
     */
	public void actionPerformed( ActionEvent e )
	{
		if ( isValid( createSearchText() ) )
			((MainFrame)getMasterContainer()).setResults();
	}

	/**
     * Gets the query from the search expression
     */
	public Query getQuery()
	{
		return new Query( createSearchText() );
	}

	/**
     * Validates the search expression. A search expression is valid if it
     * has at least one keyword and in case it has more it must have an 
     * operator in front of each extra keyword. Example "hello +all"
     */
	private boolean isValid( String text )
	{
		if ( text.indexOf( " " ) != -1 )
		{
			String[] expression = text.split( " " );
			
			for ( int i=1; i<expression.length; i++ )
			{
				if ( !expression[i].startsWith(
						String.valueOf(Query.activeOperators[0])) &&
					 !expression[i].startsWith(
					 	String.valueOf(Query.activeOperators[1]))  )
				{
					JOptionPane.showMessageDialog(this,
						"Every keyword besides the first one must start with" +
						" an operator (+,|)");
					return false;
				}
			}
		}
	
		return true;
	}
	
	private String createSearchText()
	{
		String text = _searchTextField.getText().trim();
		
		if ( text.indexOf( " " ) != -1 )
		{
			if ( text.indexOf( String.valueOf(Query.activeOperators[0])) == -1 
				&& text.indexOf( 
					String.valueOf(Query.activeOperators[1])) == -1 )
			{
				String[] expression = text.split( " " );
				for ( int i=1; i<expression.length; i++ )
					expression[i] = "|" + expression[i];
				
				text = "";
				for ( int i=0; i<expression.length; i++ )
					text += expression[i] + " ";
			}
		}

		return text;
	}
}