package TextDatabase;

/**
 * @author Costas Vandikas (vandikas@csd.uoc.gr)
 */

import java.io.FileReader;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.FileNotFoundException;

/**
 * The WordReader class reads words from a file
 */
public class WordReader extends BufferedReader
{
	/**
     * Holds the linefeed character
     */
	public static final int LineFeed = 10;
	/**
     * Holds the carriage return character
     */
	public static final int CarriageReturn = 13;
	/**
     * Holds the capital A character
     */
	public static final int CapitalA = 65;
	/**
     * Holds the capital Z character
     */
	public static final int CapitalZ = 90;
	/**
     * Holds the small A character
     */
	public static final int SmallA = 97;
	/**
     * Holds the small Z character
     */
	public static final int SmallZ = 122;
	/**
     * Holds the distance betweeen small and capital characters
     */
	public static final int CapitalToSmallDistance = 32;
	/**
     * Holds the End Of File character
     */
	public static final int EndOfFile = -1;

	/**
     * Initializes the WordReader
     */
	public WordReader( String FileName ) throws FileNotFoundException
	{
		super( new FileReader( FileName ) );
	}

	/**
     * Reads a word by reading character after character, 
     * converting it to lower case. The process is finished when a word
     * delimeter is reached. This function accepts only characters and
     * ignores numbers.
     */
	public String ReadWord() throws IOException
	{
		int ch = -1;
		String word = "";
		do
		{
			ch = read();
			
			if ( ch >= CapitalA && ch <= CapitalZ )
				ch += CapitalToSmallDistance;
			
			if ( ch >= SmallA && ch <= SmallZ )
				word += (char)ch;
		}
		while( !isCharDelimeter(ch) );
		
		return word;
	}

	/**
     * A word delimeter is character such as the Carriage Return,
     * End Of File, Space, Comma, Dot, Dash...
     */
	private boolean isCharDelimeter( int ch )
	{
		return ( ch == CarriageReturn || ch == EndOfFile || 
			ch == ' ' || ch == ',' || ch == '.' || ch == '-' );
	}
}